#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-options-z-options-internal
version:              1.2.1.2
package-name:         options
lib-name:             options-internal
id:                   options-1.2.1.2-8fuKMTkms8E1lnDRtNJTxi-options-internal
key:                  options-1.2.1.2-8fuKMTkms8E1lnDRtNJTxi-options-internal
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  f7b8e154cad03c684d2c5cb1ed2e1796
exposed-modules:
    Options.Help Options.Tokenize Options.Types Options.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-8fuKMTkms8E1lnDRtNJTxi-options-internal
depends:
    base-4.18.2.1 containers-0.6.7
    monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 options
version:              1.2.1.2
visibility:           public
id:                   options-1.2.1.2-LrT1BlOeGOU5PBPbPiDZDq
key:                  options-1.2.1.2-LrT1BlOeGOU5PBPbPiDZDq
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  89d68f9e93f6ef3ddc3b498196a117cb
exposed:              True
exposed-modules:      Options
import-dirs:          /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-LrT1BlOeGOU5PBPbPiDZDq
depends:
    base-4.18.2.1 containers-0.6.7
    monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u
    options-1.2.1.2-8fuKMTkms8E1lnDRtNJTxi-options-internal

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

